#
# spec file for package libvisual
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libvisual
VCS: https://src.suse.de/ALP-pool/libvisual#60eaa4da3f4aa61020daacad3df7862b3cb21071
Version:        0.4.0
Release:        7.6
%ifarch ppc64
# bug437293
Obsoletes:      libvisual-64bit
%endif
Summary:        Sound Visualization Library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Sound/Visualization
URL:            http://localhost.nl/~synap/libvisual-wiki/index.php/Main_Page
Source:         %name-%{version}.tar.bz2
Source2:        baselibs.conf
Patch0:         %name-%{version}.diff
Patch1:         %name-%{version}-compiler_warnings.diff
Patch2:         libvisual.visual_cpu_get_altivec.patch
Patch3:         %name-%{version}-unref-static.diff
Patch4:         libvisual-0.4.0-2.1-nmu.diff
Patch5:         libvisual-0.4.0-inlinedefineconflict.patch
BuildRequires:  freeglut-devel
BuildRequires:  gcc-build-c++
BuildRequires:  libdrm-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
Libvisual is a library that acts as a middle layer between applications
that need audio visualization and audio visualization plug-ins.

%package -n libvisual-0_4-0
Summary:        Sound Visualization library
Group:          System/Libraries

%description -n libvisual-0_4-0
Libvisual is a library that acts as a middle layer between applications
that need audio visualization and audio visualization plug-ins.

%package devel
Summary:        Headers for the libvisual sound visualization library
Group:          Productivity/Multimedia/Sound/Visualization
Requires:       glibc-devel
Requires:       libvisual-0_4-0 = %{version}-%{release}
# bug437293
%ifarch ppc64
Obsoletes:      libvisual-devel-64bit
%endif

%description devel
Libvisual is a library that acts as a middle layer between applications
that want audio visualisation and audio visualisation plugins.

This library is used by amaroK for example.

%prep
%setup -q
%patch0
%patch1
%patch2 -p1
%patch3
%patch4 -p1
%patch5 -p1

%build
autoreconf -fiv
%if %suse_version > 1000
CFLAGS="%optflags -fstack-protector"
%endif
%ifarch %ix86
CFLAGS="%optflags -mmmx"
%else
CFLAGS="%optflags"
%endif
export CFLAGS="$CFLAGS -fno-strict-aliasing"
%configure --disable-static
%make_build

%install
%make_install
for i in morph input actor transform; do
	mkdir -p %buildroot/%_libdir/%name/$i %buildroot/%_datadir/%name/$i
done
rm -v %buildroot/%_libdir/*.la
# *fixme*
rm -rf %buildroot/%_datadir/locale

%post   -n libvisual-0_4-0 -p /sbin/ldconfig
%postun -n libvisual-0_4-0 -p /sbin/ldconfig

%files -n libvisual-0_4-0
%_libdir/libvisual-0.4.so.*
%_libdir/libvisual
%_datadir/libvisual

%files devel
%doc AUTHORS README ChangeLog NEWS TODO
%license COPYING
%_includedir/libvisual-0.4
%_libdir/pkgconfig/libvisual-0.4.pc
%_libdir/libvisual-0.4.so

%changelog
* Mon Nov  6 2023 dimstar@opensuse.org
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Wed May 11 2022 jengelh@inai.de
- Remove old specfile constructs
- Remove --with-pic, this is only useful with --enable-static
- Make %%install sh-compatible
- Remove .la files, I do not think we will need it
- Repair rpmlint error "libvisual.x86_64: E:
  shlib-policy-name-error SONAME: libvisual-0.4.so.0, expected
  package suffix: 0_4-0"
* Sat Feb  2 2013 coolo@suse.com
- update license to new format
* Thu Jul 26 2012 dvaleev@suse.com
- defining inline causes problems trying to build against
  libvisual headers
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 22 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Oct 21 2011 mls@suse.de
- do not use /usr/src/packages in specfile
* Fri Jun 24 2011 anixx@opensuse.org
- added a patch from Debian to fix build
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Nov 12 2008 crrodriguez@suse.de
- use -fno-strict-aliasing to avoid breakages.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Jun 11 2007 schwab@suse.de
- Fix unref on const object.
* Tue Nov 21 2006 olh@suse.de
- disable altivec [#219960]
* Tue Aug 29 2006 mskibbe@suse.de
- fix some compiler warnings
- fix bug 199443 - libvisual-0.4.0-2: local variable used before
  set
* Tue Jul  4 2006 cthiel@suse.de
- update to version 0.4.0
  * Real time timestamping support.
  * Will unref plugins that don't match the ABI version.
  * Added VisRectangle system.
  * New BMP loader that supports all depths and RLE encoding.
  * visual_mem_set(), visual_mem_set16(), visual_mem_set32()
    Optimized memset functions.
  * VisVideo new composite system.
  * VisVideo sub regions.
  * visual_video_zoom_*().
  * visual_video_mirror_*().
  * visual_video_rotate_*().
  * Removed obsolete visual_video_depth_transform_to_buffer().
  * Added VisCollection system.
  * Added VisHashmap.
  * Added VisCache.
  * VisAudio rewrite.
  * Added .license bit to VisPluginInfo for realtime license check.
  * Removed .struct_size and .api_version from the VisPluginInfo structure,
    and revamped the plugin version check system. Put
    VISUAL_PLUGIN_API_VERSION_VALIDATOR somewhere in your plugin and it'll
    work.
  * Homedir installable plugins ~/.libvisual/actor transform morph input.
  * Added VisOS. Realtime priority functions are hosted in this module.
  * Added VisMath. All kind of math related functions have been added, most
    note worthy are the _vectorized_. All of these are accelerated by
    mmx/3dnow/sse instructions.
  * VisFourier completely revamped.
* Tue Feb 28 2006 hvogel@suse.de
- include transform directorys for plugins [#154112]
* Fri Feb  3 2006 ro@suse.de
- Stack Protector only for > 10.0
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 hvogel@suse.de
- Make use of Stack Protector
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Thu Jun 23 2005 hvogel@suse.de
- remove build directory from dependency_libs
* Mon May  9 2005 ro@suse.de
- use mmx on x86
* Thu Feb 10 2005 adrian@suse.de
- update to official version 0.2.0
* Tue Feb  8 2005 hvogel@suse.de
- fix build on ppc
* Wed Feb  2 2005 hvogel@suse.de
- update to latest CVS (upcomming 0.2.0)
* Mon Nov 22 2004 hvogel@suse.de
- the directorys do not belong to the devel subpackage
* Thu Nov 11 2004 hvogel@suse.de
- include some directorys the libvisual plugins need
* Thu Oct 28 2004 adrian@suse.de
- update to version 0.1.7
* Mon Oct 11 2004 adrian@suse.de
- initial package of version 0.1.6
